DefaultDelegate<Q, R> class abstract

A delegate for when running on Dart VM.

Constructors

DefaultDelegate({required FutureOr<R> callback(Q message)})
Creates a DefaultDelegate with a single argument callback to be called when running on Dart VM.
const
factory

Properties

callback → FutureOr<R> Function(Q message)
The callback that will be called when the app is running on Dart VM (Android, iOS, macOS, etc).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited