JsDelegate class abstract

A delegate for when running on Web.

Constructors

JsDelegate({required dynamic callback, Future fallback()?})
Creates a JsDelegate with a single argument callback to be called when running on Web.
const
factory

Properties

callback → dynamic
The callback name declared in the web worker. This should either be a String or a List of String, otherwise it will throw AssertionError on debug mode.
no setter
fallback → Future Function()?
The fallback function that will be called by JsIsolatedWorker when Web Worker is not available on the user's browser.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited