WorkerDelegate<Q, R> class abstract

A worker delegate for both Dart's Isolate and Web Worker.

Constructors

WorkerDelegate({required Object key, required DefaultDelegate<Q, R> defaultDelegate, required JsDelegate jsDelegate})
Creates a new WorkerDelegate that consists of its key, defaultDelegate for when running on Dart VM, and jsDelegate for when running on Web.
const
factory

Properties

defaultDelegate → DefaultDelegate<Q, R>
The delegate for when running on Web.
no setter
hashCode → int
The hash code for this object.
no setterinherited
jsDelegate → JsDelegate
The delegate for when running on Dart VM.
no setter
key → Object
The key associated to this WorkerDelegate.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited